@@ -261,10 +261,7 @@ impl Modules {
                 if module_span.is_dummy() {
                     return None;
                 }
-                Some(format!(
-                    "{}\n",
-                    cm.lookup_source_file(module_span.lo).name.to_string()
-                ))
+                Some(format!("{}\n", cm.lookup_source_file(module_span.lo).name))
             })
             .collect::<String>();
         let mut cloned = self.clone();
